@@ -116,6 +116,7 @@ class HTTPTransport(BaseTransport):
         self,
         verify: VerifyTypes = True,
         cert: CertTypes = None,
+        http1: bool = True,
         http2: bool = False,
         limits: Limits = DEFAULT_LIMITS,
         trust_env: bool = True,
@@ -133,6 +134,7 @@ class HTTPTransport(BaseTransport):
                 max_connections=limits.max_connections,
                 max_keepalive_connections=limits.max_keepalive_connections,
                 keepalive_expiry=limits.keepalive_expiry,
+                http1=http1,
                 http2=http2,
                 uds=uds,
                 local_address=local_address,
@@ -143,7 +145,6 @@ class HTTPTransport(BaseTransport):
             self._pool = httpcore.SyncHTTPProxy(
                 proxy_url=proxy.url.raw,
                 proxy_headers=proxy.headers.raw,
-                proxy_mode=proxy.mode,
                 ssl_context=ssl_context,
                 max_connections=limits.max_connections,
                 max_keepalive_connections=limits.max_keepalive_connections,
@@ -211,6 +212,7 @@ class AsyncHTTPTransport(AsyncBaseTransport):
         self,
         verify: VerifyTypes = True,
         cert: CertTypes = None,
+        http1: bool = True,
         http2: bool = False,
         limits: Limits = DEFAULT_LIMITS,
         trust_env: bool = True,
@@ -228,6 +230,7 @@ class AsyncHTTPTransport(AsyncBaseTransport):
                 max_connections=limits.max_connections,
                 max_keepalive_connections=limits.max_keepalive_connections,
                 keepalive_expiry=limits.keepalive_expiry,
+                http1=http1,
                 http2=http2,
                 uds=uds,
                 local_address=local_address,
@@ -238,7 +241,6 @@ class AsyncHTTPTransport(AsyncBaseTransport):
             self._pool = httpcore.AsyncHTTPProxy(
                 proxy_url=proxy.url.raw,
                 proxy_headers=proxy.headers.raw,
-                proxy_mode=proxy.mode,
                 ssl_context=ssl_context,
                 max_connections=limits.max_connections,
                 max_keepalive_connections=limits.max_keepalive_connections,
